@@ -12,7 +12,7 @@ use constant FSTAB_LENGTH => 6;
 
 ##no critic (InputOutput::ProhibitBacktickOperators)
 
-$VERSION = '0.7901';
+$VERSION = '0.7903';
 
 sub init {
     my $self = shift;
@@ -187,7 +187,9 @@ sub _parse_swap {
 
 sub _ip {
     my $self = shift;
-    my $raw  = qx(ifconfig);
+    my $cmd  = q{/sbin/ifconfig};
+    return if ! -e $cmd || ! -x _;
+    my $raw = qx($cmd);
     return if not $raw;
     my @raw = split /inet addr/xms, $raw;
     return if ! @raw || @raw < 2 || ! $raw[1];
@@ -287,8 +289,8 @@ Sys::Info::Driver::Linux::OS - Linux backend
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7901> of C<Sys::Info::Driver::Linux::OS>
-released on C<16 July 2012>.
+This document describes version C<0.7903> of C<Sys::Info::Driver::Linux::OS>
+released on C<8 May 2013>.
 
 -
 
@@ -340,7 +342,7 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
