@@ -1,8 +1,11 @@
 package Sys::Info::Driver::Linux::OS::Distribution;
 use strict;
 use warnings;
-use constant STD_RELEASE => 'lsb-release';
+use constant STD_RELEASE     => 'lsb-release';
 use constant STD_RELEASE_DIR => 'lsb-release.d';
+use constant DEBIAN_RELEASE  => 'os-release';
+use constant STD_ETC_DIR     => '/etc';
+
 use base qw( Sys::Info::Base );
 use Carp qw( croak );
 use Sys::Info::Driver::Linux;
@@ -10,7 +13,7 @@ use Sys::Info::Driver::Linux::Constants qw( :all );
 use Sys::Info::Driver::Linux::OS::Distribution::Conf;
 use File::Spec;
 
-our $VERSION = '0.7901';
+our $VERSION = '0.7903';
 
 # XXX: <REMOVE>
 my $RELX = sub {
@@ -30,6 +33,12 @@ my %DERIVED_RELEASE  = $RELX->('release_derived');
 
 sub new {
     my $class = shift;
+    my %option;
+    if ( @_ ) {
+        die "Parameters must be in name => value format" if @_ % 2;
+        %option = @_;
+    }
+
     my $self  = {
         DISTRIB_ID          => q{},
         DISTRIB_NAME        => q{}, # workround field for new distros
@@ -40,7 +49,12 @@ sub new {
         pattern             => q{},
         PROBE               => undef,
         RESULTS             => undef,
+        etc_dir             => STD_ETC_DIR,
+        %option,
     };
+
+    $self->{etc_dir} =~ s{[/]+$}{}xms;
+
     bless $self, $class;
     $self->_initial_probe;
     return $self;
@@ -81,14 +95,17 @@ sub _probe_name {
 }
 
 sub _probe_release {
-    my($self, $r) = @_;;
+    my($self, $r) = @_;
+
     foreach my $id ( keys %{ $r } ) {
-        if ( -f "/etc/$id" && ! -l "/etc/$id" ) {
+        my $file = File::Spec->catfile( $self->{etc_dir}, $id );
+        if ( -f $file && ! -l $file ) {
             $self->{DISTRIB_ID}   = $r->{ $id };
             $self->{release_file} = $id;
             return $self->{DISTRIB_ID};
         }
     }
+
     return;
 }
 
@@ -208,43 +225,66 @@ sub _get_lsb_info {
     my $field = shift || 'DISTRIB_ID';
     my $tmp   = $self->{release_file};
 
-    if ( -r File::Spec->catfile( '/etc', STD_RELEASE ) ) {
-        $self->{release_file} = STD_RELEASE;
+    my($rfile) = grep { -r $_->[1] }
+                map  {
+                    [ $_ => File::Spec->catfile( $self->{etc_dir}, $_ ) ]
+                }
+                STD_RELEASE,
+                DEBIAN_RELEASE
+                ;
+
+    if ( $rfile ) {
+        $self->{release_file} = $rfile->[0];
         $self->{pattern}      = $field . '=(.+)';
         my $info = $self->_get_file_info;
         return $self->{$field} = $info if $info;
     }
     else {
         # CentOS6+? RHEL? Any new distro?
-        my $dir = File::Spec->catdir( '/etc', STD_RELEASE_DIR );
+        my $dir = File::Spec->catdir( $self->{etc_dir}, STD_RELEASE_DIR );
         if ( -d $dir ) {
-            my $rv = map  { s{$dir/}{}xms && $_ }
-                 grep { $_ !~ m{ \A [.] }xms }
-                 glob "$dir/*";
+            my $rv = join q{: },
+                     map  { m{$dir/(.*)}xms ? $1 : () }
+                     grep { $_ !~ m{ \A [.] }xms }
+                     glob "$dir/*";
             $self->{LSB_VERSION} = $rv if $rv;
         }
         my($release) = do {
-            my @files = glob "/etc/*release";
-            my($real) = sort grep { ! -l } @files;
-            my %uniq  = map { $self->trim( $self->slurp( $_ ) ) => 1 }
-                        @files;
-            if ( $real ) {
-                ($self->{release_file} = $real) =~ s{/etc/}{}xms;
-                $self->{pattern}       = '(.+)';
+            if ( my @files = glob $self->{etc_dir} . "/*release" ) {
+                my($real) = sort grep { ! -l } @files;
+                my %uniq  = map { $self->trim( $self->slurp( $_ ) ) => 1 }
+                            @files;
+                if ( $real ) {
+                    my $etc = $self->{etc_dir};
+                    ($self->{release_file} = $real) =~ s{$etc/}{}xms;
+                    $self->{pattern}       = '(.+)';
+                }
+                keys %uniq;
             }
-            keys %uniq;
         };
+
         return if ! $release; # huh?
+
         my($rname) = split m{\-}xms, $self->{release_file};
         my($distrib_id, @rest)  = split m{release}xms, $release, 2;
         my($version, $codename) = split m{ \s+   }xms, $self->trim( join ' ', @rest ), 2;
-        $codename   =~ s{[()]}{}xmsg;
+        $codename   =~ s{[()]}{}xmsg if $codename;
         $distrib_id = $self->trim( $distrib_id );
         $self->{DISTRIB_DESCRIPTION} = $release;
         $self->{DISTRIB_ID}          = $rname || $distrib_id;
         $self->{DISTRIB_NAME}        = $distrib_id;
         $self->{DISTRIB_RELEASE}     = $version;
-        $self->{DISTRIB_CODENAME}    = $codename;
+        $self->{DISTRIB_CODENAME}    = $codename || q{};
+
+        # fix stupidity
+        if (   $self->{DISTRIB_ID}
+            && $self->{DISTRIB_ID} eq 'redhat'
+            && $self->{DISTRIB_NAME}
+            && index($self->{DISTRIB_NAME}, 'CentOS') != -1
+        ) {
+            $self->{DISTRIB_ID} = 'centos';
+        }
+
         return $self->{ $field } if $self->{ $field };
     }
 
@@ -255,10 +295,10 @@ sub _get_lsb_info {
 
 sub _get_file_info {
     my $self = shift;
-    my $file = File::Spec->catfile( '/etc', $self->{release_file} );
+    my $file = File::Spec->catfile( $self->{etc_dir}, $self->{release_file} );
     require IO::File;
     my $FH = IO::File->new;
-    $FH->open( $file, '<' ) || croak "Cannot open $file: $!";
+    $FH->open( $file, '<' ) || croak "Can't open $file: $!";
     my @raw = <$FH>;
     $FH->close || croak "Can't close FH($file): $!";
     my $rv;
@@ -298,8 +338,8 @@ Sys::Info::Driver::Linux::OS::Distribution - Linux distribution probe
 
 =head1 DESCRIPTION
 
-This document describes version C<0.7901> of C<Sys::Info::Driver::Linux::OS::Distribution>
-released on C<16 July 2012>.
+This document describes version C<0.7903> of C<Sys::Info::Driver::Linux::OS::Distribution>
+released on C<8 May 2013>.
 
 This is a simple module that tries to guess on what linux distribution
 we are running by looking for release's files in /etc.  It now looks for
@@ -354,7 +394,7 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2012 Burak Gursoy. All rights reserved.
+Copyright 2006 - 2013 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
